@@ -1,5 +1,9 @@
-import contextlib
+from typing import Optional
 
+from django.conf import settings
+from django.contrib.auth import get_user_model
+
+from auditlog.cid import set_cid
 from auditlog.context import set_actor
 
 
@@ -11,9 +15,14 @@ class AuditlogMiddleware:
 
     def __init__(self, get_response=None):
         self.get_response = get_response
+        if not isinstance(settings.AUDITLOG_DISABLE_REMOTE_ADDR, bool):
+            raise TypeError("Setting 'AUDITLOG_DISABLE_REMOTE_ADDR' must be a boolean")
 
     @staticmethod
     def _get_remote_addr(request):
+        if settings.AUDITLOG_DISABLE_REMOTE_ADDR:
+            return None
+
         # In case there is no proxy, return the original address
         if not request.headers.get("X-Forwarded-For"):
             return request.META.get("REMOTE_ADDR")
@@ -29,13 +38,30 @@ class AuditlogMiddleware:
 
         return remote_addr
 
+    @staticmethod
+    def _get_remote_port(request) -> Optional[int]:
+        remote_port = request.headers.get("X-Forwarded-Port", "")
+
+        try:
+            remote_port = int(remote_port)
+        except ValueError:
+            remote_port = None
+
+        return remote_port
+
+    @staticmethod
+    def _get_actor(request):
+        user = getattr(request, "user", None)
+        if isinstance(user, get_user_model()) and user.is_authenticated:
+            return user
+        return None
+
     def __call__(self, request):
         remote_addr = self._get_remote_addr(request)
+        remote_port = self._get_remote_port(request)
+        user = self._get_actor(request)
 
-        if hasattr(request, "user") and request.user.is_authenticated:
-            context = set_actor(actor=request.user, remote_addr=remote_addr)
-        else:
-            context = contextlib.nullcontext()
+        set_cid(request)
 
-        with context:
+        with set_actor(actor=user, remote_addr=remote_addr, remote_port=remote_port):
             return self.get_response(request)
